@@ -1,7 +1,7 @@
 package Media::Info;
 
 our $DATE = '2016-04-06'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -56,6 +56,9 @@ sub get_media_info {
         next unless eval { require $mod_pm; 1 };
         my $func = \&{"$mod\::get_media_info"};
         my $res = $func->(media => $args{media});
+        if ($res->[0] == 200) {
+            $res->[3]{'func.backend'} = $backend;
+        }
         return $res unless $res->[0] == 412;
     }
 
@@ -81,7 +84,7 @@ Media::Info - Return information on media file/URL
 
 =head1 VERSION
 
-This document describes version 0.09 of Media::Info (from Perl distribution Media-Info), released on 2016-04-06.
+This document describes version 0.10 of Media::Info (from Perl distribution Media-Info), released on 2016-04-06.
 
 =head1 SYNOPSIS
 
